@@ -24,7 +24,7 @@
 
 #include "k3bqprocess.h"
 #include "k3b_export.h"
-#include <KCoreAddons/KProcess>
+#include <KProcess>
 
 class K3bKProcessPrivate;
 
@@ -76,7 +76,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~K3bKProcess();
+    ~K3bKProcess() override;
 
     /**
      * Set how to handle the output channels of the child process.
